@@ -189,6 +189,9 @@ _gst_tag_initialize (void)
   gst_tag_register (GST_TAG_COPYRIGHT_URI, GST_TAG_FLAG_META,
       G_TYPE_STRING, _("copyright uri"),
       _("URI to the copyright notice of the data"), NULL);
+  gst_tag_register (GST_TAG_ENCODED_BY, GST_TAG_FLAG_META, G_TYPE_STRING,
+      _("encoded by"), _("name of the encoding person or organization"),
+      gst_tag_merge_strings_with_comma);
   gst_tag_register (GST_TAG_CONTACT, GST_TAG_FLAG_META,
       G_TYPE_STRING,
       _("contact"), _("contact information"), gst_tag_merge_strings_with_comma);
