@@ -35,8 +35,8 @@ void		gst_util_set_value_from_string	(GValue *value, const gchar *value_str);
 void		gst_util_set_object_arg		(GObject *object, const gchar *name, const gchar *value);
 void		gst_util_dump_mem		(const guchar *mem, guint size);
 
-guint64         gst_util_gdouble_to_guint64     (gdouble value)  G_GNUC_PURE;
-gdouble         gst_util_guint64_to_gdouble     (guint64 value)  G_GNUC_PURE;
+guint64         gst_util_gdouble_to_guint64     (gdouble value)  G_GNUC_CONST;
+gdouble         gst_util_guint64_to_gdouble     (guint64 value)  G_GNUC_CONST;
 
 /**
  * gst_guint64_to_gdouble:
@@ -63,13 +63,13 @@ gdouble         gst_util_guint64_to_gdouble     (guint64 value)  G_GNUC_PURE;
 #define         gst_guint64_to_gdouble(value)   ((gdouble) (value))
 #endif
 
-guint64		gst_util_uint64_scale		(guint64 val, guint64 num, guint64 denom) G_GNUC_PURE;
-guint64		gst_util_uint64_scale_round	(guint64 val, guint64 num, guint64 denom) G_GNUC_PURE;
-guint64		gst_util_uint64_scale_ceil	(guint64 val, guint64 num, guint64 denom) G_GNUC_PURE;
+guint64		gst_util_uint64_scale		(guint64 val, guint64 num, guint64 denom);
+guint64		gst_util_uint64_scale_round	(guint64 val, guint64 num, guint64 denom);
+guint64		gst_util_uint64_scale_ceil	(guint64 val, guint64 num, guint64 denom);
 
-guint64         gst_util_uint64_scale_int       (guint64 val, gint num, gint denom) G_GNUC_PURE;
-guint64         gst_util_uint64_scale_int_round (guint64 val, gint num, gint denom) G_GNUC_PURE;
-guint64         gst_util_uint64_scale_int_ceil  (guint64 val, gint num, gint denom) G_GNUC_PURE;
+guint64         gst_util_uint64_scale_int       (guint64 val, gint num, gint denom);
+guint64         gst_util_uint64_scale_int_round (guint64 val, gint num, gint denom);
+guint64         gst_util_uint64_scale_int_ceil  (guint64 val, gint num, gint denom);
 
 guint32         gst_util_seqnum_next            (void);
 gint32          gst_util_seqnum_compare         (guint32 s1, guint32 s2);
@@ -123,16 +123,13 @@ static void type_as_function ## _init	       (type          *object,	\
                                                 type ## Class *g_class);\
 static parent_type ## Class *parent_class = NULL;			\
 static void								\
-type_as_function ## _class_init_trampoline (gpointer g_class,		\
-					    gpointer data)		\
+type_as_function ## _class_init_trampoline (gpointer g_class)		\
 {									\
   parent_class = (parent_type ## Class *)				\
       g_type_class_peek_parent (g_class);				\
   type_as_function ## _class_init ((type ## Class *)g_class);		\
 }									\
 									\
-GType type_as_function ## _get_type (void);				\
-									\
 GType									\
 type_as_function ## _get_type (void)					\
 {									\
@@ -147,7 +144,7 @@ type_as_function ## _get_type (void)					\
 	sizeof (type ## Class),						\
         type_as_function ## _base_init,					\
         NULL,		  /* base_finalize */				\
-        type_as_function ## _class_init_trampoline,			\
+        (GClassInitFunc) type_as_function ## _class_init_trampoline,    \
         NULL,		  /* class_finalize */				\
         NULL,               /* class_data */				\
         sizeof (type),							\
@@ -219,7 +216,7 @@ type_as_function ## _implements_interface_init (GstImplementsInterfaceClass *kla
 }                                                                       \
                                                                         \
 static void                                                             \
-type_as_function ## _init_interfaces (GType type)                       \
+type_as_function ## _init_interfaces (GType type_var)                   \
 {                                                                       \
   static const GInterfaceInfo implements_iface_info = {                 \
     (GInterfaceInitFunc) type_as_function ## _implements_interface_init,\
@@ -232,9 +229,9 @@ type_as_function ## _init_interfaces (GType type)                       \
     NULL,                                                               \
   };                                                                    \
                                                                         \
-  g_type_add_interface_static (type, GST_TYPE_IMPLEMENTS_INTERFACE,     \
+  g_type_add_interface_static (type_var, GST_TYPE_IMPLEMENTS_INTERFACE, \
       &implements_iface_info);                                          \
-  g_type_add_interface_static (type, interface_type_as_macro,		\
+  g_type_add_interface_static (type_var, interface_type_as_macro,	\
       &iface_info);							\
 }                                                                       \
                                                                         \
@@ -272,7 +269,7 @@ GST_BOILERPLATE_FULL (type, type_as_function, parent_type,              \
 
 /* Define PUT and GET functions for unaligned memory */
 #define _GST_GET(__data, __idx, __size, __shift) \
-    (((guint##__size) (((guint8 *) (__data))[__idx])) << (__shift))
+    (((guint##__size) (((const guint8 *) (__data))[__idx])) << (__shift))
 
 #define _GST_PUT(__data, __idx, __size, __shift, __num) \
     (((guint8 *) (__data))[__idx] = (((guint##__size) (__num)) >> (__shift)) & 0xff)
@@ -995,8 +992,9 @@ GST_WRITE_DOUBLE_BE(guint8 *data, gdouble num)
  */
 #define GST_ROUND_DOWN_64(num) ((num)&(~63))
 
-void			gst_object_default_error	(GstObject * source,
-							 GError * error, gchar * debug);
+void			gst_object_default_error	(GstObject    * source,
+							 const GError * error,
+							 const gchar  * debug);
 
 /* element functions */
 void                    gst_element_create_all_pads     (GstElement *element);
@@ -1020,6 +1018,9 @@ void                    gst_element_unlink_many         (GstElement *element_1,
 
 gboolean		gst_element_link_pads           (GstElement *src, const gchar *srcpadname,
 		                                         GstElement *dest, const gchar *destpadname);
+gboolean		gst_element_link_pads_full      (GstElement *src, const gchar *srcpadname,
+		                                         GstElement *dest, const gchar *destpadname,
+							 GstPadLinkCheck flags);
 void                    gst_element_unlink_pads         (GstElement *src, const gchar *srcpadname,
 		                                         GstElement *dest, const gchar *destpadname);
 
@@ -1033,8 +1034,14 @@ gboolean                gst_element_seek_simple         (GstElement   *element,
                                                          gint64        seek_pos);
 
 /* util elementfactory functions */
-gboolean		gst_element_factory_can_src_caps(GstElementFactory *factory, const GstCaps *caps);
-gboolean		gst_element_factory_can_sink_caps(GstElementFactory *factory, const GstCaps *caps);
+#ifndef GST_DISABLE_DEPRECATED
+gboolean		gst_element_factory_can_src_caps    (GstElementFactory *factory, const GstCaps *caps);
+gboolean		gst_element_factory_can_sink_caps   (GstElementFactory *factory, const GstCaps *caps);
+#endif /* GST_DISABLE_DEPRECATED */
+gboolean gst_element_factory_can_sink_all_caps (GstElementFactory *factory, const GstCaps *caps);
+gboolean gst_element_factory_can_src_all_caps  (GstElementFactory *factory, const GstCaps *caps);
+gboolean gst_element_factory_can_sink_any_caps (GstElementFactory *factory, const GstCaps *caps);
+gboolean gst_element_factory_can_src_any_caps  (GstElementFactory *factory, const GstCaps *caps);
 
 /* util query functions */
 gboolean                gst_element_query_position      (GstElement *element, GstFormat *format,
@@ -1166,6 +1173,26 @@ gpointer                gst_util_array_binary_search      (gpointer array, guint
 							   GstSearchMode mode, gconstpointer search_data,
 							   gpointer user_data);
 
+gint gst_util_greatest_common_divisor (gint a, gint b);
+void gst_util_fraction_to_double (gint src_n, gint src_d, gdouble *dest);
+void gst_util_double_to_fraction (gdouble src, gint *dest_n, gint *dest_d);
+gboolean gst_util_fraction_multiply (gint a_n, gint a_d, gint b_n, gint b_d, gint *res_n, gint *res_d);
+gboolean gst_util_fraction_add (gint a_n, gint a_d, gint b_n, gint b_d, gint *res_n, gint *res_d);
+gint gst_util_fraction_compare (gint a_n, gint a_d, gint b_n, gint b_d);
+
+
+/* sink message event
+ *
+ * FIXME: This should be in gstevent.h but can't because
+ * it needs GstMessage and this would introduce circular
+ * header includes. And forward declarations of typedefs
+ * are unfortunately not possible. The implementation of
+ * these functions is in gstevent.c.
+ */
+GstEvent*       gst_event_new_sink_message      (GstMessage *msg);
+void            gst_event_parse_sink_message    (GstEvent *event, GstMessage **msg);
+
+
 G_END_DECLS
 
 #endif /* __GST_UTILS_H__ */
